module fft_val_define

  double precision, allocatable, dimension(:,:) :: zi     ! array of psi

  real, allocatable, dimension(:,:) :: psid   ! array of psi
  real, allocatable, dimension(:,:) :: ud     ! array of u
  real, allocatable, dimension(:,:) :: vd     ! array of v
  real, allocatable, dimension(:,:) :: zd     ! array of zeta
  double precision, allocatable, dimension(:,:) :: tmpr  ! temporary array
  double precision, allocatable, dimension(:,:) :: tmpi  ! temporary array

  complex(kind(0d0)), allocatable, dimension(:,:) :: ur    ! array of psi
  complex(kind(0d0)), allocatable, dimension(:,:) :: vr    ! array of psi
  complex(kind(0d0)), allocatable, dimension(:,:) :: zor    ! array of psi
  complex(kind(0d0)), allocatable, dimension(:,:) :: psior  ! array of psi
  complex(kind(0d0)), allocatable, dimension(:,:) :: psiko
  complex(kind(0d0)), allocatable, dimension(:,:) :: zko
  complex(kind(0d0)), allocatable, dimension(:,:) :: psikn
  complex(kind(0d0)), allocatable, dimension(:,:) :: zkn
  complex(kind(0d0)), allocatable, dimension(:,:) :: zkt
  complex(kind(0d0)), allocatable, dimension(:,:) :: zopt1
  complex(kind(0d0)), allocatable, dimension(:,:) :: uk
  complex(kind(0d0)), allocatable, dimension(:,:) :: vk

!-- For ISPACK

  double precision, allocatable, dimension(:,:) :: zor_isp
  double precision, allocatable, dimension(:,:) :: psior_isp
  double precision, allocatable, dimension(:,:) :: ur_isp
  double precision, allocatable, dimension(:,:) :: vr_isp
  double precision, allocatable, dimension(:,:) :: zko_isp
  double precision, allocatable, dimension(:,:) :: psiko_isp
  double precision, allocatable, dimension(:,:) :: uk_isp
  double precision, allocatable, dimension(:,:) :: vk_isp
  double precision, allocatable, dimension(:,:) :: tmp_work

end module fft_val_define
